"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.Timeline = void 0;

var _react = _interopRequireDefault(require("react"));

var _range = _interopRequireDefault(require("lodash/range"));

var _styles = require("@material-ui/core/styles");

var _useColors = _interopRequireDefault(require("../../hooks/use-colors"));

var _TimeStamp = _interopRequireDefault(require("../TimeStamp"));

var _formatTime = require("../../utils/format-time");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

var Container = (0, _styles.styled)("div")(function (_ref) {
  var width = _ref.width,
      themeColors = _ref.themeColors;
  return {
    width: width,
    overflow: "hidden",
    position: "relative",
    height: 64,
    borderBottom: "1px solid ".concat(themeColors.Selection),
    color: themeColors.fg
  };
});
var TimeText = (0, _styles.styled)("div")(function (_ref2) {
  var x = _ref2.x,
      faded = _ref2.faded;
  return {
    display: "inline-block",
    width: 80,
    fontSize: 12,
    fontVariantNumeric: "tabular-nums",
    position: "absolute",
    left: x,
    borderLeft: "1px solid rgba(255,255,255,0.5)",
    paddingLeft: 4,
    whiteSpace: "pre-wrap",
    opacity: faded ? 0.25 : 0.75
  };
});
var Svg = (0, _styles.styled)("svg")({
  position: "absolute",
  left: 0,
  bottom: 0
});

var Timeline = function Timeline(_ref3) {
  var timeFormat = _ref3.timeFormat,
      visibleTimeStart = _ref3.visibleTimeStart,
      visibleTimeEnd = _ref3.visibleTimeEnd,
      width = _ref3.width,
      _ref3$timestamps = _ref3.timestamps,
      timestamps = _ref3$timestamps === void 0 ? [] : _ref3$timestamps,
      gridLineMetrics = _ref3.gridLineMetrics,
      onClickTimestamp = _ref3.onClickTimestamp,
      onRemoveTimestamp = _ref3.onRemoveTimestamp;
  var themeColors = (0, _useColors.default)();
  var visibleDuration = visibleTimeEnd - visibleTimeStart; // TODO compute tick count using width

  var timeTextCount = Math.ceil(width / 100);
  var timeTextTimes = (0, _range.default)(timeTextCount).map(function (i) {
    return visibleTimeStart + visibleDuration / timeTextCount * i;
  });
  var numberOfMajorGridLines = gridLineMetrics.numberOfMajorGridLines,
      majorGridLinePixelOffset = gridLineMetrics.majorGridLinePixelOffset,
      majorGridLinePixelDistance = gridLineMetrics.majorGridLinePixelDistance;
  return /*#__PURE__*/_react.default.createElement(Container, {
    themeColors: themeColors,
    width: width
  }, (0, _range.default)(timeTextCount).map(function (timeTextIndex) {
    return /*#__PURE__*/_react.default.createElement(TimeText, {
      key: timeTextIndex,
      x: timeTextIndex / timeTextCount * width,
      faded: timeTextTimes[timeTextIndex] < 0
    }, (0, _formatTime.formatTime)(timeTextTimes[timeTextIndex], timeFormat, visibleDuration));
  }), /*#__PURE__*/_react.default.createElement(Svg, {
    width: width,
    height: 12
  }, (0, _range.default)(numberOfMajorGridLines).map(function (tickIndex) {
    var x = majorGridLinePixelOffset + majorGridLinePixelDistance * tickIndex;
    return /*#__PURE__*/_react.default.createElement("line", {
      key: tickIndex,
      x1: x,
      x2: x,
      y1: 0,
      y2: 12,
      stroke: themeColors.base01
    });
  })), timestamps.map(function (timestamp, i) {
    var left = (timestamp.time - visibleTimeStart) / visibleDuration * width;
    return /*#__PURE__*/_react.default.createElement(_TimeStamp.default, _extends({
      key: i,
      left: left
    }, timestamp, {
      onClick: function onClick() {
        return onClickTimestamp(timestamp, i);
      },
      onRemove: function onRemove() {
        return onRemoveTimestamp(timestamp, i);
      }
    }));
  }));
};

exports.Timeline = Timeline;
var _default = Timeline;
exports.default = _default;